GWPCA
=====

.. currentmodule:: xeofs.single

.. autoclass:: GWPCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GWPCA.__init__
      ~GWPCA.components
      ~GWPCA.compute
      ~GWPCA.deserialize
      ~GWPCA.explained_variance
      ~GWPCA.explained_variance_ratio
      ~GWPCA.fit
      ~GWPCA.fit_transform
      ~GWPCA.get_params
      ~GWPCA.get_serialization_attrs
      ~GWPCA.inverse_transform
      ~GWPCA.largest_locally_weighted_components
      ~GWPCA.load
      ~GWPCA.save
      ~GWPCA.scores
      ~GWPCA.serialize
      ~GWPCA.transform
   
   

   
   
   